@@ -32,6 +32,9 @@
 #'        \code{\link{search_geocomponents}}. Availability of geocomponent
 #'        depends on summary level.
 #' @param with_margin  read also margin of error in addition to estimate
+#' @param dec_fill whether to fill geo_headers codes with data from decennial
+#'        census. The #'        codes in ACS summary file are incomplete.
+#'        "dec2010" using decennial census 2010 data.
 #' @param show_progress  whether to show progress in fread()
 
 #'
@@ -74,6 +77,7 @@ read_acs1year <- function(year,
                           summary_level = NULL,
                           geo_comp = "total",
                           with_margin = FALSE,
+                          dec_fill = NULL,
                           show_progress = TRUE){
 
     ### check if the path to census is set ###
@@ -159,13 +163,13 @@ read_acs1year <- function(year,
     if (!is.null(areas)){
         dt <- read_acs1year_areas_(
             year, states, table_contents, areas, summary_level, geo_comp,
-            with_margin, show_progress
+            with_margin, dec_fill, show_progress
         )
     } else {
         geo_headers <- unique(geo_headers)
         dt <- read_acs1year_geoheaders_(
             year, states, table_contents, geo_headers, summary_level, geo_comp,
-            with_margin, show_progress
+            with_margin, dec_fill, show_progress
         )
     }
 
@@ -197,10 +201,10 @@ read_acs1year <- function(year,
 
 
 read_acs1year_filesegment_ <- function(year,
-                          state,
-                          file_seg,
-                          est_marg = "e",
-                          show_progress = TRUE){
+                                       state,
+                                       file_seg,
+                                       est_marg = "e",
+                                       show_progress = TRUE){
     # read all data in a file segment and assign right column names
 
     path_to_census <- Sys.getenv("PATH_TO_CENSUS")
@@ -222,7 +226,8 @@ read_acs1year_filesegment_ <- function(year,
     }
 
     dt <- tryCatch({
-        fread(file, header = FALSE, showProgress = show_progress) %>%
+        fread(file, header = FALSE, showProgress = show_progress,
+              integer64 = "numeric") %>%
             setnames(col_names)
     }, error = function(err){
         message("\nPlease double check the original data: ")
@@ -366,6 +371,7 @@ read_acs1year_areas_ <- function(year,
                                  summary_level = "*",
                                  geo_comp = "*",
                                  with_margin = FALSE,
+                                 dec_fill = NULL,
                                  show_progress = TRUE){
     # read ACS 1-year data of selected areas
     #
@@ -398,9 +404,9 @@ read_acs1year_areas_ <- function(year,
 
     lst_state <- list()
     for (st in states) {
-            geo <- read_acs1year_geo_(year, st, geo_headers,
-                                      show_progress = show_progress) %>%
-                setkey(LOGRECNO)
+        geo <- read_acs1year_geo_(year, st, geo_headers,
+                                  show_progress = show_progress) %>%
+            setkey(LOGRECNO)
 
 
 
@@ -421,8 +427,14 @@ read_acs1year_areas_ <- function(year,
             acs <- geo
         }
 
-        # add coordinates
-        acs <- add_coord(acs, st)
+        # add coordinates from census 2010 data
+        if (is.null(dec_fill)){
+            acs <- add_coord(acs, st)
+        } else if (dec_fill == "dec2010"){
+            acs[, (geo_headers) := NULL]
+            acs <- add_coord(acs, st, geo_headers)
+        }
+
 
         lst_state[[st]] <- acs[SUMLEV %like% summary_level & GEOCOMP %like% geo_comp]
 
@@ -448,9 +460,10 @@ read_acs1year_areas_ <- function(year,
                              STUSAB %like% dt_areas[x, state]] %>%
                 .[, area := dt_areas[x, name]]
         ) %>%
-            rbindlist() %>%
-            # no use of the geoheaders
-            .[, unique(dt_areas[, geoheader]) := NULL]
+            rbindlist()
+        # %>%
+        #     # no use of the geoheaders
+        #     .[, unique(dt_areas[, geoheader]) := NULL]
     }
 
     # reorder columns
@@ -463,7 +476,7 @@ read_acs1year_areas_ <- function(year,
     } else {
         contents <- table_contents
     }
-    setcolorder(selected, c(begin, contents, end))
+    setcolorder(selected, c(begin, geo_headers, contents, end))
 
     return(selected)
 }
@@ -478,6 +491,7 @@ read_acs1year_geoheaders_ <- function(year,
                                       summary_level = "*",
                                       geo_comp = "*",
                                       with_margin = FALSE,
+                                      dec_fill = NULL,
                                       show_progress = TRUE){
     # read ACS 1-year data of selected geoheaders
     #
@@ -521,12 +535,17 @@ read_acs1year_geoheaders_ <- function(year,
             acs <- geo
         }
 
-        # add coordinates from Census 2010 data
-        acs <- add_coord(acs, st)
+        # add coordinates from census 2010 data
+        if (is.null(dec_fill)){
+            acs <- add_coord(acs, st)
+        } else if (dec_fill == "dec2010"){
+            acs[, (geo_headers) := NULL]
+            acs <- add_coord(acs, st, geo_headers)
+        }
 
 
         lst_state[[st]] <- acs[SUMLEV %like% summary_level &
-                               GEOCOMP %like% geo_comp]
+                                   GEOCOMP %like% geo_comp]
     }
 
     combined <- rbindlist(lst_state) %>%
